netapp_ontap.resources.cifs_search_path API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved …

# Module `netapp_ontap.resources.cifs_search_path`

Copyright © 2020 NetApp Inc. All rights reserved.

## Overview

ONTAP home directory functionality can be used to create home directories for SMB users on the CIFS server and automatically offer each user a dynamic share to their home directory without creating an individual SMB share for each user.

The home directory search path is a set of absolute paths from the root of an SVM that directs ONTAP to search for home directories. If there are multiple search paths, ONTAP tries them in the order specified until it finds a valid path. To use the CIFS home directories feature, at least one home directory search path must be added for an SVM.

## Examples

### Creating a home directory search path

To create a home directory search path, use the following API. Note the return_records=true query parameter used to obtain the newly created entry in the response.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import CifsSearchPath

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = CifsSearchPath()
        resource.path = "/"
        resource.svm.name = "vs1"
        resource.svm.uuid = "a41fd873-ecf8-11e8-899d-0050568e9333"
        resource.post(hydrate=True)
        print(resource)

Try it out

    CifsSearchPath(
        {
            "path": "/",
            "svm": {"name": "vs1", "uuid": "a41fd873-ecf8-11e8-899d-0050568e9333"},
        }
    )

### Retrieving the CIFS home directory search paths configuration for all SVMs in the cluster

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import CifsSearchPath

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        print(list(CifsSearchPath.get_collection(fields="*", return_timeout=15)))

Try it out

    [
        CifsSearchPath(
            {
                "path": "/",
                "index": 1,
                "svm": {"name": "vs1", "uuid": "2d96f9aa-f4ce-11e8-b075-0050568e278e"},
            }
        ),
        CifsSearchPath(
            {
                "path": "/a",
                "index": 2,
                "svm": {"name": "vs1", "uuid": "2d96f9aa-f4ce-11e8-b075-0050568e278e"},
            }
        ),
        CifsSearchPath(
            {
                "path": "/",
                "index": 1,
                "svm": {"name": "vs2", "uuid": "4f23449b-f4ce-11e8-b075-0050568e278e"},
            }
        ),
        CifsSearchPath(
            {
                "path": "/1",
                "index": 2,
                "svm": {"name": "vs2", "uuid": "4f23449b-f4ce-11e8-b075-0050568e278e"},
            }
        ),
    ]

### Retrieving a specific home directory searchpath configuration for an SVM

The configuration returned is identified by the UUID of its SVM and the index (position) in the list of search paths that is searched to find a home directory of a user.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import CifsSearchPath

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = CifsSearchPath(
            index=2, **{"svm.uuid": "2d96f9aa-f4ce-11e8-b075-0050568e278e"}
        )
        resource.get()
        print(resource)

Try it out

    CifsSearchPath(
        {
            "path": "/a",
            "index": 2,
            "svm": {"name": "vs1", "uuid": "2d96f9aa-f4ce-11e8-b075-0050568e278e"},
        }
    )

### Reordering a specific home drectory search path in the list

An entry in the home directory search path list can be reordered to a new positin by specifying the 'new_index' field. The reordered configuration is identified by the UUID of its SVM and the index.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import CifsSearchPath

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = CifsSearchPath(
            index=2, **{"svm.uuid": "2d96f9aa-f4ce-11e8-b075-0050568e278e"}
        )
        resource.patch(hydrate=True, new_index=1)

### Removing a specific home directory search path for an SVM

The entry being removed is identified by the UUID of its SVM and the index.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import CifsSearchPath

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = CifsSearchPath(
            index=2, **{"svm.uuid": "2d96f9aa-f4ce-11e8-b075-0050568e278e"}
        )
        resource.delete()

## Classes

`class CifsSearchPath (*args, **kwargs)`

  This is a list of CIFS home directory search paths. When a CIFS client connects to a home directory share, these paths are searched in the order indicated by the position field to find the home directory of the connected CIFS client.

  Initialize the instance of the resource.

  Any keyword arguments are set on the instance as properties. For example, if the class was named 'MyResource', then this statement would be true:

      MyResource(name='foo').name == 'foo'

  ## Args

  `*args`
    Each positional argument represents a parent key as used in the URL of the object. That is, each value will be used to fill in a segment of the URL which refers to some parent object. The order of these arguments must match the order they are specified in the URL, from left to right.
  `**kwargs`
    each entry will have its key set as an attribute name on the instance and its value will be the value of that attribute.

  ### Ancestors

  - Resource

  ### Static methods

  `def count_collection(*args, connection: HostConnection = None, **kwargs) -> int`

    Retrieves CIFS home directory search paths.

    ### Related ONTAP commands

    - `cifs server home-directory search-path show`

    ### Learn more

    - `DOC /protocols/cifs/home-directory/search-paths`

    Fetch a count of all objects of this type from the host.

    This calls GET on the object to determine the number of records. It is more efficient than calling get_collection() because it will not construct any objects. Query parameters can be passed in as kwargs to determine a count of objects that match some filtered criteria.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the count of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. These query parameters can affect the count. A return_records query param will be ignored.

    ## Returns

    On success, returns an integer count of the objects of this type. On failure, returns -1.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400, or if there is no connection available to use either passed in or on the library.

  `def delete_collection(*args, body: typing.Union = None, connection: HostConnection = None, **kwargs) -> NetAppResponse`

    Deletes a CIFS home directory search path.

    ### Related ONTAP commands

    - `cifs server home-directory search-path remove`

    ### Learn more

    - `DOC /protocols/cifs/home-directory/search-paths`

    Delete all objects in a collection which match the given query.

    All records on the host which match the query will be deleted.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to delete the collection of bars for a particular foo, the foo.name value should be passed.
    `body`
      The body of the delete request. This could be a Resource instance or a dictionary object.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. Only resources matching this query will be patched.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def find(*args, connection: HostConnection = None, **kwargs) -> Resource`

    Retrieves CIFS home directory search paths.

    ### Related ONTAP commands

    - `cifs server home-directory search-path show`

    ### Learn more

    - `DOC /protocols/cifs/home-directory/search-paths`

    Find an instance of an object on the host given a query.

    The host will be queried with the provided key/value pairs to find a matching resource. If 0 are found, None will be returned. If more than 1 is found, an error will be raised or returned. If there is exactly 1 matching record, then it will be returned.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to find a bar for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `Resource` object containing the details of the object or None if no matches were found.

    ## Raises

    `NetAppRestError`: If the API call returned more than 1 matching resource.

  `def get_collection(*args, connection: HostConnection = None, max_records: int = None, **kwargs) -> typing.Iterable`

    Retrieves CIFS home directory search paths.

    ### Related ONTAP commands

    - `cifs server home-directory search-path show`

    ### Learn more

    - `DOC /protocols/cifs/home-directory/search-paths`

    Fetch a list of all objects of this type from the host.

    This is a lazy fetch, making API calls only as necessary when the result of this call is iterated over. For instance, if max_records is set to 5, then iterating over the collection causes an API call to be sent to the server once for every 5 records. If the client stops iterating before getting to the 6th record, then no additional API calls are made.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the collection of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `max_records`
      The maximum number of records to return per call
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A list of `Resource` objects

    ## Raises

    `NetAppRestError`: If there is no connection available to use either passed in or on the library. This would be not be raised when get_collection() is called, but rather when the result is iterated.

  `def patch_collection(body: dict, *args, connection: HostConnection = None, **kwargs) -> NetAppResponse`

    Reorders a CIFS home directory search path.

    ### Related ONTAP commands

    - `cifs server home-directory search-path reorder`

    ### Learn more

    - `DOC /protocols/cifs/home-directory/search-paths`

    Patch all objects in a collection which match the given query.

    All records on the host which match the query will be patched with the provided body.

    ## Args

    `body`
      A dictionary of name/value pairs to set on all matching members of the collection.
    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to patch the collection of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. Only resources matching this query will be patched.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Methods

  `def delete(self, body: typing.Union = None, poll: bool = True, poll_interval: typing.Union = None, poll_timeout: typing.Union = None, **kwargs) -> NetAppResponse`

    Deletes a CIFS home directory search path.

    ### Related ONTAP commands

    - `cifs server home-directory search-path remove`

    ### Learn more

    - `DOC /protocols/cifs/home-directory/search-paths`

    Send a deletion request to the host for this object.

    ## Args

    `body`
      The body of the delete request. This could be a Resource instance or a dictionary object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def get(self, **kwargs) -> NetAppResponse`

    Retrieves a CIFS home directory search path of an SVM.

    ### Related ONTAP commands

    - `cifs server home-directory search-path show`

    ### Learn more

    - `DOC /protocols/cifs/home-directory/search-paths`

    Fetch the details of the object from the host.

    Requires the keys to be set (if any). After returning, new or changed properties from the host will be set on the instance.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def patch(self, hydrate: bool = False, poll: bool = True, poll_interval: typing.Union = None, poll_timeout: typing.Union = None, **kwargs) -> NetAppResponse`

    Reorders a CIFS home directory search path.

    ### Related ONTAP commands

    - `cifs server home-directory search-path reorder`

    ### Learn more

    - `DOC /protocols/cifs/home-directory/search-paths`

    Send the difference in the object's state to the host as a modification request.

    Calculates the difference in the object's state since the last time we interacted with the host and sends this in the request body.

    ## Args

    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of the object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `**kwargs`
      Any key/value pairs passed will normally be sent as query parameters to the host. If any of these pairs are parameters that are sent as formdata then only parameters of that type will be accepted and all others will be discarded.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def post(self, hydrate: bool = False, poll: bool = True, poll_interval: typing.Union = None, poll_timeout: typing.Union = None, **kwargs) -> NetAppResponse`

    Creates a home directory search path.

    ### Required properties

    - `svm.uuid` or `svm.name` - Existing SVM in which to create the home directory search path.
    - `path` - Path in the owning SVM namespace that is used to search for home directories.

    ### Related ONTAP commands

    - `cifs server home-directory search-path add`

    ### Learn more

    - `DOC /protocols/cifs/home-directory/search-paths`

    Send this object to the host as a creation request.

    ## Args

    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of the object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `**kwargs`
      Any key/value pairs passed will normally be sent as query parameters to the host. If any of these pairs are parameters that are sent as formdata then only parameters of that type will be accepted and all others will be discarded.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Inherited members

  - `Resource`:
    - `from_dict`
    - `get_collection_url`
    - `get_connection`
    - `instance_location`
    - `path_keys`
    - `poll`
    - `set_connection`
    - `to_dict`
`class CifsSearchPathSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the CifsSearchPath object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `index GET`

    The position in the list of paths that is searched to find the home directory of the CIFS client. Not available in POST.

  `path GET POST`

    The file system path that is searched to find the home directory of the CIFS client.

    Example: /HomeDirectory/EngDomain

  `svm GET POST PATCH`

    The svm field of the cifs_search_path.